Cheetah.Tests.Template module — Cheetah3 - The Python-Powered Template Engine

# Cheetah.Tests.Template module

class `Cheetah.Tests.Template.` `ClassMethodSupport`(methodName='runTest')

  Bases: `Cheetah.Tests.Template.TemplateTest`

  `test_BasicDecorator`()

class `Cheetah.Tests.Template.` `ClassMethods_compile`(methodName='runTest')

  Bases: `Cheetah.Tests.Template.TemplateTest`

  I am using the same Cheetah source for each test to root out clashes caused by the compile caching in Template.compile().

  `test_baseclassArg`()
  `test_basicUsage`()
  `test_classNameArg`()
  `test_compilationCache`()
  `test_keepRefToGeneratedCodeArg`()
  `test_mainMethodNameArg`()
  `test_moduleFileCaching`()
  `test_moduleGlobalsArg`()
  `test_moduleNameArg`()

class `Cheetah.Tests.Template.` `ClassMethods_subclass`(methodName='runTest')

  Bases: `Cheetah.Tests.Template.TemplateTest`

  `test_basicUsage`()

class `Cheetah.Tests.Template.` `MultipleInheritanceSupport`(methodName='runTest')

  Bases: `Cheetah.Tests.Template.TemplateTest`

  `runTest`()

class `Cheetah.Tests.Template.` `Preprocessors`(methodName='runTest')

  Bases: `Cheetah.Tests.Template.TemplateTest`

  `test_basicUsage1`()
  `test_complexUsage`()
  `test_i18n`()
  `test_normalizePreprocessorArgVariants`()

class `Cheetah.Tests.Template.` `StaticMethodSupport`(methodName='runTest')

  Bases: `Cheetah.Tests.Template.TemplateTest`

  `test_BasicDecorator`()

class `Cheetah.Tests.Template.` `SubclassSearchListTest`(methodName='runTest')

  Bases: `Cheetah.Tests.Template.TemplateTest`

  Verify that if we subclass Template, we can still use attributes on that subclass in the searchList

  `runTest`()

class `Cheetah.Tests.Template.` `TemplateTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

class `Cheetah.Tests.Template.` `TryExceptImportTest`(methodName='runTest')

  Bases: `Cheetah.Tests.Template.TemplateTest`

  `test_FailCase`()

    Test situation where an inline #import statement will get relocated